import { DeepPartial, ISeriesApi, SeriesDataItemTypeMap, SeriesMarker, SeriesOptionsMap, SeriesType, Time } from 'lightweight-charts';
import * as React from 'react';
export interface SeriesProps<TSeriesType extends SeriesType> {
    /**
     * Data for display, used for `series.setData()`.
     * Memoization is recommended to prevent setting multiple times.
     */
    data?: SeriesDataItemTypeMap[TSeriesType][];
    /**
     * Used to pass the incremental data, used for `series.update()`.
     */
    latestItem?: SeriesDataItemTypeMap[TSeriesType];
    /**
     * Series options, please refer to `lightweight-charts` documents.
     * Memoization is recommended to prevent calling `series.applyOptions()` multiple times.
     */
    options?: DeepPartial<SeriesOptionsMap[TSeriesType]>;
    /**
     * Used to display series marker via `series.setMarkers()`
     * Memoization is recommended to prevent calling `series.setMarkers()` multiple times.
     */
    markers?: SeriesMarker<Time>[];
    /**
     * Only `<PriceLine />` is accepted, unknown behavior may occurs otherwise.
     */
    children?: React.ReactNode;
}
declare type SeriesRender<TSeriesType extends SeriesType> = SeriesProps<TSeriesType> & React.RefAttributes<ISeriesApi<TSeriesType> | undefined>;
export declare type Series<TSeriesType extends SeriesType> = React.ForwardRefExoticComponent<SeriesRender<TSeriesType>>;
/**
 * Create an area series for the chart
 *
 * ❗Only use inside `<Chart />`.
 */
export declare const AreaSeries: Series<'Area'>;
/**
 * Create a bar series for the chart.
 *
 * ❗Only use inside `<Chart />`.
 */
export declare const BarSeries: Series<'Bar'>;
/**
 * Create a baseline series for the chart.
 *
 * ❗Only use inside `<Chart />`.
 */
export declare const BaselineSeries: Series<'Baseline'>;
/**
 * Create a candlestick series for the chart.
 *
 * ❗Only use inside `<Chart />`.
 */
export declare const CandlestickSeries: Series<'Candlestick'>;
/**
 * Create a histogram series for the chart.
 *
 * ❗Only use inside `<Chart />`.
 */
export declare const HistogramSeries: Series<'Histogram'>;
/**
 * Create a line series for the chart.
 *
 * ❗Only use inside `<Chart />`.
 */
export declare const LineSeries: Series<'Line'>;
export {};
