import { DependencyList } from 'react';
export interface ChartFitContentTriggerProps {
    /**
     * Dependency list for retriggering the `chart.timeScale().fitContent()` function.
     *
     * ❗Should not change the array length since it will be used like
     * ```js
     * useEffect(effect, [...deps])
     * ```
     */
    deps?: DependencyList | undefined;
}
/**
 * Utility component for triggering `chart.timeScale().fitContent()` depends on dependency list `deps`.
 *
 * ❗Only use inside `<Chart />`.
 * Turn chart option `disableAutoContentFitOnInit = true` to prevent multiple fit content called.
 * @example
 * ```js
 * const App = () => {
 *   const data = useMemo(() => getData(), []);
 *   return (
 *     <Chart disableAutoContentFitOnInit>
 *       <AreaSeries data={data} />
 *       <ChartFitContentTrigger deps={[data]}>
 *     </Chart>
 *   );
 * }
 * ```
 */
export declare const ChartFitContentTrigger: ({ deps, }: ChartFitContentTriggerProps) => null;
